/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.framework;

import java.io.File;
import java.io.IOException;



import org.gfxtest.common.PostScriptRendererConfiguration;



/**
 * This class performs conversion from a PostScript file to a PNG file.
 * 
 * @author Pavel Tisnovsky
 */
public class PostScriptToPngConverter
{
    /**
     * Configuration of a PostScript software RIP
     */
    static PostScriptRendererConfiguration configuration = null;

    /**
     * Do the conversion from PostScript file to a PNG image.
     *
     * @param printOutputFile
     * @param pngOutputFile
     */
    public static void convert(File printOutputFile, File pngOutputFile)
    {
        // load configuration and put it to a "cache"
        if (configuration == null)
        {
            configuration = new PostScriptRendererConfiguration();
        }

        // prepare command for PostScript RIP
        String command = prepareCommand(printOutputFile, pngOutputFile);
        Runtime rt = Runtime.getRuntime();
        try
        {
            // run PostScript RIP and wait for its finish
            Process proc =rt.exec(command);
            proc.waitFor();
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
        catch (InterruptedException e)
        {
            e.printStackTrace();
        }
    }

    /**
     * Construct a command for a PostScript software RIP
     * 
     * @param printOutputFile
     * @param pngOutputFile
     * @return command to be called via @see Runtime#exec
     */
    private static String prepareCommand(File printOutputFile, File pngOutputFile)
    {
        // renderer name and its basic parameters
        String cmd = configuration.getRendererName() + " " + configuration.getRendererOptions() + " ";
        // DPI specifier
        String res = "-r" + configuration.getDpi() + " ";
        // output file name
        String output = "-o " + pngOutputFile.getPath() + " ";
        // input file name
        String input = " " + printOutputFile.getPath();
        // put it all together
        return cmd + res + output + input + " >> out 2>> err";
    }

}
