/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

package org.gfxtest.framework;



/**
 * Abstract class used by all print tests, ie all tests
 * which renders all drawing into a PostScript file.
 * 
 * @author Pavel Tisnovsky
 */
abstract public class PrintTest extends GfxTest
{
    /**
     * Border around the test picture. It's better to not to draw into the
     * border due to PostScript renderers differences.
     */
    protected static final int BORDER = 10;

    /**
     * Maximum width of line or other open shape rendered onto a paper.
     */
    protected static final float MAX_STROKE_WIDTH = 15.0f;

    /**
     * Minimum width of line or other open shape rendered onto a paper.
     */
    protected static final float MIN_STROKE_WIDTH = 0.0f;

    /**
     * Change of stroke width in each test iteration.
     */
    protected static final float STROKE_WIDTH_DELTA = 0.5f;

    /**
     * Change of stroke width in each test iteration for diagonal lines.
     */
    protected static final float STROKE_WIDTH_DIAGONAL_DELTA = 0.2f;

    /**
     * Offset between two circles in each test iteration.
     */
    protected static final int CIRCLE_RADIUS_STEP = 10;

    /**
     * Offset between two ellipses in each test iteration.
     */
    protected static final int ELLIPSE_RADIUS_STEP = 10;

    /**
     * Offset between two arcs in each test iteration.
     */
    protected static final int ARC_RADIUS_STEP = 10;

    /**
     * Minimum radius of a circle or an arc.
     */
    protected static final int MINIMUM_RADIUS = 10;

    /**
     * Horizontal distance between two lines in each test iteration.
     */
    protected static final int HORIZONTAL_STEP = 10;

    /**
     * Vertical distance between two lines in each test iteration.
     */
    protected static final int VERTICAL_STEP = 10;

    /**
     * Diagonal distance between two lines in each test iteration.
     */
    protected static final int DIAGONAL_STEP = 16;

    /**
     * Diagonal distance between cubic curves in each test iteration.
     */
    protected static final int CUBIC_CURVE_STEP= 16;

    /**
     * Diagonal distance between quadratic curves in each test iteration.
     */
    protected static final int QUADRATIC_CURVE_STEP= 16;

    /**
     * Horizontal and also vertical distance between rectangles lines in each test iteration.
     */
    protected static final int RECTANGLE_STEP = 10;

    /**
     * Horizontal and also vertical distance between polylines in each test iteration.
     */
    protected static final int POLYLINE_STEP = 10;

    /**
     * Horizontal and also vertical distance between polygons in each test iteration.
     */
    protected static final int POLYGON_STEP = 10;

    /**
     * Maximum color index.
     * (used only in tests which uses color palette)
     */
    protected static final int MAX_COLOR_INDEX = 1000;
}
